traditional_chinese_word_dict = {
    # Main
    "application_name": "AutoControlGUI",
    # Widget
    "interval_time": "間隔時間（秒）：",
    "cursor_x": "滑鼠游標 X 軸位置：",
    "cursor_y": "滑鼠游標 Y 軸位置：",
    "mouse_button": "滑鼠按鍵：",
    "keyboard_button": "鍵盤按鍵：",
    "click_type": "點擊類型：",
    "input_method": "輸入方式：",
    "mouse_radio": "滑鼠",
    "keyboard_radio": "鍵盤",
    "repeat_until_stopped_radio": "重複直到停止",
    "repeat_radio": "重複",
    "times": "次數",
    "start": "開始",
    "stop": "停止",
}
